@@ -15,7 +15,8 @@ See L<Net::WebSocket::Endpoint::Server>.
 use strict;
 use warnings;
 
-use IO::Sys ();
+use Call::Context ();
+use IO::SigGuard ();
 
 use Net::WebSocket::Frame::close ();
 use Net::WebSocket::Frame::ping ();
@@ -24,12 +25,12 @@ use Net::WebSocket::Message ();
 use Net::WebSocket::PingStore ();
 use Net::WebSocket::X ();
 
-use constant DEFAULT_MAX_PINGS => 10;
+use constant DEFAULT_MAX_PINGS => 3;
 
 sub new {
     my ($class, %opts) = @_;
 
-    my @missing = grep { !length $opts{$_} } qw( parser out );
+    my @missing = grep { !length $opts{$_} } qw( parser );
     #die "Missing: [@missing]" if @missing;
 
     my $self = {
@@ -43,10 +44,11 @@ sub new {
 
         (map { defined($opts{$_}) ? ( "_$_" => $opts{$_} ) : () } qw(
             parser
-            out
             max_pings
 
             on_data_frame
+
+            out
             before_send_control_frame
         )),
     };
@@ -127,12 +129,12 @@ sub check_heartbeat {
 }
 
 sub shutdown {
-    my ($self, $reason) = @_;
+    my ($self, %opts) = @_;
 
     my $close = Net::WebSocket::Frame::close->new(
         $self->FRAME_MASK_ARGS(),
-        code => 'ENDPOINT_UNAVAILABLE',
-        reason => $reason,
+        code => $opts{'code'} || 'ENDPOINT_UNAVAILABLE',
+        reason => $opts{'reason'},
     );
 
     my $write_func = $self->_get_write_func();
@@ -152,7 +154,7 @@ sub is_closed {
 sub get_write_queue_size {
     my ($self) = @_;
 
-    return ($self->{'_partially_written_frame'} || 0) + @{ $self->{'_frames_queue'} };
+    return ($self->{'_partially_written_frame'} ? 1 : 0) + @{ $self->{'_frames_queue'} };
 }
 
 sub shift_write_queue {
@@ -167,14 +169,14 @@ sub process_write_queue {
     $self->_verify_not_closed();
 
     if ($self->{'_partially_written_frame'}) {
-        if ( $self->_write_bytes_no_prehook( @{ $self->{'_partially_written_frame'} } ) ) {
+        if ( $self->_write_bytes_no_prehook( $self->{'_partially_written_frame'} ) ) {
             undef $self->{'_partially_written_frame'};
         }
     }
     else {
         my $qi = shift @{ $self->{'_frames_queue'} } or die 'process_write_queue() on empty!';
 
-        $self->_write_now( @$qi );
+        $self->_write_now( $qi );
     }
 
     return;
@@ -210,13 +212,13 @@ sub on_pong {
 sub _get_write_func {
     my ($self) = @_;
 
-    return $self->{'_out'}->blocking() ? '_write_now' : '_enqueue_write';
+    return $self->{'_out'} ? '_write_now' : '_enqueue_write';
 }
 
 sub _enqueue_write {
     my $self = shift;
 
-    push @{ $self->{'_frames_queue'} }, \@_;
+    push @{ $self->{'_frames_queue'} }, $_[0];
 
     return;
 }
@@ -325,7 +327,7 @@ sub _write_bytes_no_prehook {
 
     local $!;
 
-    my $wrote = IO::Sys::write( $self->{'_out'}, $_[1] );
+    my $wrote = IO::SigGuard::syswrite( $self->{'_out'}, $_[1] );
 
     #Full success:
     if ($wrote == length $_[1]) {
@@ -334,7 +336,7 @@ sub _write_bytes_no_prehook {
     }
 
     #Partial write; we need to come back to this one.
-    $self->{'_partially_written_frame'} = [ substr( $_[1], $wrote ), $_[2] ];
+    $self->{'_partially_written_frame'} = substr( $_[1], $wrote );
 
     return;
 }
