@@ -10,7 +10,6 @@ Net::WebSocket::Endpoint::Server
 
     my $ept = Net::WebSocket::Endpoint::Server->new(
         parser => $parser_obj,
-        out => $out_fh,
 
         #optional, # of pings to send before we send a close
         max_pings => 5,
@@ -19,7 +18,10 @@ Net::WebSocket::Endpoint::Server
             my ($frame) = @_;
 
             #...
-        }
+        },
+
+        #only for blocking I/O
+        out => $out_fh,
     );
 
     if ( _we_timed_out_waiting_for_read_readiness() ) {
@@ -67,9 +69,7 @@ Instantiate the class. Nothing is actually done here. Options are:
 
 =over
 
-=item * C<parser> (required) - An instance of L<Net::WebSocket::Parser>
-
-=item * C<out> (required) - The endpoint’s output filehandle
+=item * C<parser> (required) - An instance of L<Net::WebSocket::Parser>.
 
 =item * C<max_pings> (optional) - The maximum # of pings to send before
 we send a C<close> frame (which ends the session).
@@ -88,6 +88,14 @@ If you want to avoid buffering a large message, you can do this:
         );
     },
 
+=item * C<out> (optional) - The endpoint’s output filehandle. This is only
+useful if your output is a blocking filehandle; otherwise, you should
+process the write queue manually via C<shift_write_queue()>.
+
+=item * C<before_send_frame> (optional) - A callback to be executed before
+the endpoint sends a ping, pong, or close frame. It receives as an argument
+the frame that will be sent.
+
 =back
 
 =head2 I<OBJ>->get_next_message()
@@ -119,12 +127,20 @@ sent immediately. That’s where the next method comes in …
 
 =head2 I<OBJ>->process_write_queue()
 
-This is only useful in non-blocking I/O contexts.
+This is only useful in non-blocking I/O contexts—and at that, probably
+only useful when you’re not using an event loop, since that loop will
+likely do its own write buffering.
 
 This will attempt to flush one frame from the write queue. If only part
 of the message is written, then the next call to this method will resume
 the output of that message.
 
+=head2 I<OBJ>->shift_write_queue()
+
+This is useful when you have an event loop so that you can feed the frames
+from the Endpoint object’s queue into the event loop’s write queue.
+It returns a single frame object, or undef if the queue is empty.
+
 =head2 I<OBJ>->check_heartbeat()
 
 Ordinarily, sends a distinct ping frame to the remote server
@@ -132,12 +148,8 @@ and increments the ping counter. Once a sent ping is
 received back (i.e., a pong), the ping counter gets reset.
 
 If the internal ping counter has already reached C<max_pings>, then we
-<<<<<<< HEAD
-send a PROTOCOL_ERROR close frame.
-=======
 send a PROTOCOL_ERROR close frame. Further I/O attempts on this object
 will prompt an appropriate exception to be thrown.
->>>>>>> master
 
 =head2 I<OBJ>->is_closed()
 
